Struct sdl2::render::RendererInfo
[−]
[src]
pub struct RendererInfo {
pub name: &'static str,
pub flags: u32,
pub texture_formats: Vec<PixelFormatEnum>,
pub max_texture_width: u32,
pub max_texture_height: u32,
}A structure that contains information on the capabilities of a render driver or the current render context.
Fields
name | |
flags | |
texture_formats | |
max_texture_width | |
max_texture_height |